powered by
Join the sets the two elements passed as arguments belong to.
union.set(i, j, ufds)
The first element in the tuple.
The second element in the tuple.
A data.table representing a UFDS.
No return value, called for side effects on rank and p.